@@ -1,7 +1,9 @@
 package HTTP::Tiny::Plugin::CustomRetry;
 
-our $DATE = '2020-08-14'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-08-15'; # DATE
+our $DIST = 'HTTP-Tiny-Plugin-CustomRetry'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -55,7 +57,7 @@ sub after_request {
 }
 
 1;
-# ABSTRACT: Retry failed request
+# ABSTRACT: (DEPRECATED) Retry failed request
 
 __END__
 
@@ -65,11 +67,11 @@ __END__
 
 =head1 NAME
 
-HTTP::Tiny::Plugin::CustomRetry - Retry failed request
+HTTP::Tiny::Plugin::CustomRetry - (DEPRECATED) Retry failed request
 
 =head1 VERSION
 
-This document describes version 0.002 of HTTP::Tiny::Plugin::CustomRetry (from Perl distribution HTTP-Tiny-Plugin-CustomRetry), released on 2020-08-14.
+This document describes version 0.003 of HTTP::Tiny::Plugin::CustomRetry (from Perl distribution HTTP-Tiny-Plugin-CustomRetry), released on 2020-08-15.
 
 =head1 SYNOPSIS
 
@@ -84,7 +86,7 @@ This document describes version 0.002 of HTTP::Tiny::Plugin::CustomRetry (from P
 =head1 DESCRIPTION
 
 B<DEPRECATION NOTICE:> This plugin is now deprecated, in favor of
-L<HTTP::Tiny::Plugin::Retry> which will merge its features.
+L<HTTP::Tiny::Plugin::Retry> which now supports L<Algorithm::Backoff> too.
 
 This plugin retries failed response using one of available backoff strategy in
 C<Algorithm::Backoff::*> (e.g. L<Algorithm::Backoff::Exponential>).
